@@ -1,13 +1,9 @@
 import json
-
 import allure
 import boto3
 import pandas as pd
 import time, os
 import logging
-# from matplotlib import pyplot as plt
-# import numpy as np
-# import seaborn as sn
 import s3fs
 from toolkit_w.internal.api_requestor import APIRequestor
 from toolkit_w.internal.token_json import UserToken
@@ -633,6 +629,11 @@ class MyWhatify:
         """
         return my_toolkit.Connector.get_s3_path(user_token=user_token)
 
+    @classmethod
+    def get_data_file_s3(cls, file_name: str):
+        logging.info("Deprecated func: get_data_file_s3, please use read_to_pandas_df function")
+        return cls.read_to_pandas_df(file_name=file_name)
+
     @classmethod
     def read_to_pandas_df(cls, file_name: str, user_token: str = None, **kwargs):
         """
@@ -643,6 +644,7 @@ class MyWhatify:
         Returns:
             panda var with the file
         """
+        logging.info('getting csv of data file from S3 for file_name: ' + str(file_name))
         return my_toolkit.Connector.read_to_pandas_df(file_name=file_name, user_token=user_token, **kwargs)
 
     @classmethod
@@ -662,11 +664,6 @@ class MyWhatify:
     ###   old data_file       ###
     #############################
 
-    @classmethod
-    def get_data_file_s3(cls, data_name='car_sdk_demo.csv'):
-        logging.info('getting csv from data file from S3 for data_name: ' + str(data_name))
-        return cls.read_to_pandas_df(file_name=data_name)
-
     @classmethod
     def get_data_file(cls, data_name='car_sdk_demo.csv'):
         with allure.step('getting csv from data file for data_name: ' + str(data_name)):
@@ -675,30 +672,26 @@ class MyWhatify:
             path = os.path.join(os.path.dirname(__file__), 'data_source/', data_name)
         return pd.read_csv(path)
 
-    @classmethod
-    def get_created_data_file(cls, data_name='temp.csv'):
-        df_data = cls.get_data_file(data_name='car_sdk_demo_test_no.csv')
-        data = df_data.get_values()
-        script_dir = os.path.dirname(__file__)
-        path = os.path.join(script_dir, '../data_source/') + data_name
-        with open(path, 'a') as f:
-            f.write('car_id,buying,maint,doors,persons,lug_boot,junk_feature,safety')
-            for i in range(1):
-                for row in data:
-                    text = ''
-                    for index in range(row.__len__()):
-                        text += str(row.tolist().pop(index)) + ","
-                    f.write('\n' + text[:-1])
-            f.close()
+    # @classmethod
+    # def get_created_data_file(cls, data_name='temp.csv'):
+    #     df_data = cls.get_data_file(data_name='car_sdk_demo_test_no.csv')
+    #     data = df_data.get_values()
+    #     script_dir = os.path.dirname(__file__)
+    #     path = os.path.join(script_dir, '../data_source/') + data_name
+    #     with open(path, 'a') as f:
+    #         f.write('car_id,buying,maint,doors,persons,lug_boot,junk_feature,safety')
+    #         for i in range(1):
+    #             for row in data:
+    #                 text = ''
+    #                 for index in range(row.__len__()):
+    #                     text += str(row.tolist().pop(index)) + ","
+    #                 f.write('\n' + text[:-1])
+    #         f.close()
 
     #############################
     ###      Validation       ###
     #############################
 
-    @classmethod
-    def test_myAPI(cls, var: str, user_token: str = None):
-        return my_toolkit.UserManagement.test_API(var_str=var, user_token=user_token)
-
 # """
 # Lists the existing Datasources - supports filtering, sorting and pagination.
 #
